@@ -34,10 +34,8 @@
 #include "ephy-embed-single.h"
 #include "ephy-embed-type-builtins.h"
 #include "ephy-encodings.h"
-#include "ephy-favicon-cache.h"
 #include "ephy-file-helpers.h"
-#include "ephy-history.h"
-
+#include "ephy-history-service.h"
 #include "ephy-print-utils.h"
 
 #define PAGE_SETUP_FILENAME	"page-setup-gtk.ini"
@@ -51,9 +49,8 @@
 
 struct _EphyEmbedShellPrivate
 {
-	EphyHistory *global_history;
+	EphyHistoryService *global_history_service;
 	GList *downloads;
-	EphyFaviconCache *favicon_cache;
 	EphyEmbedSingle *embed_single;
 	EphyEncodings *encodings;
 	EphyAdBlockManager *adblock_manager;
@@ -95,13 +92,6 @@ ephy_embed_shell_dispose (GObject *object)
 	EphyEmbedShell *shell = EPHY_EMBED_SHELL (object);
 	EphyEmbedShellPrivate *priv = shell->priv;
 
-	if (priv->favicon_cache != NULL)
-	{
-		LOG ("Unref favicon cache");
-		g_object_unref (priv->favicon_cache);
-		priv->favicon_cache = NULL;
-	}
-
 	if (priv->encodings != NULL)
 	{
 		LOG ("Unref encodings");
@@ -137,10 +127,10 @@ ephy_embed_shell_finalize (GObject *object)
 		shell->priv->downloads = NULL;
 	}
 
-	if (shell->priv->global_history)
+	if (shell->priv->global_history_service)
 	{
-		LOG ("Unref history");
-		g_object_unref (shell->priv->global_history);
+		LOG ("Unref history service");
+		g_object_unref (shell->priv->global_history_service);
 	}
 
 	if (shell->priv->embed_single)
@@ -160,43 +150,27 @@ ephy_embed_shell_finalize (GObject *object)
 }
 
 /**
- * ephy_embed_shell_get_favicon_cache:
+ * ephy_embed_shell_get_global_history_service:
  * @shell: the #EphyEmbedShell
  *
- * Returns the favicons cache.
- *
- * Return value: (transfer none): the favicons cache
+ * Return value: (transfer none): the global #EphyHistoryService
  **/
 GObject *
-ephy_embed_shell_get_favicon_cache (EphyEmbedShell *shell)
+ephy_embed_shell_get_global_history_service (EphyEmbedShell *shell)
 {
 	g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
 
-	if (shell->priv->favicon_cache == NULL)
+	if (shell->priv->global_history_service == NULL)
 	{
-		shell->priv->favicon_cache = ephy_favicon_cache_new ();
+		char *filename;
+
+		filename = g_build_filename (ephy_dot_dir (), "ephy-history.db", NULL);
+		shell->priv->global_history_service = ephy_history_service_new (filename);
+		g_free (filename);
+		g_return_val_if_fail (shell->priv->global_history_service, NULL);
 	}
 
-	return G_OBJECT (shell->priv->favicon_cache);
-}
-
-/**
- * ephy_embed_shell_get_global_history:
- * @shell: the #EphyEmbedShell
- *
- * Return value: (transfer none):
- **/
-GObject *
-ephy_embed_shell_get_global_history (EphyEmbedShell *shell)
-{
-	g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
-
-	if (shell->priv->global_history == NULL)
-	{
-		shell->priv->global_history = ephy_history_new ();
-	}
-
-	return G_OBJECT (shell->priv->global_history);
+	return G_OBJECT (shell->priv->global_history_service);
 }
 
 static GObject *
