@@ -45,10 +45,11 @@ typedef enum
 typedef enum
 {
 	EPHY_PREFS_STATE_HISTORY_DATE_FILTER_LAST_HALF_HOUR,
-	EPHY_PREFS_STATE_HISTORY_DATE_FILTER_EVER,
 	EPHY_PREFS_STATE_HISTORY_DATE_FILTER_TODAY,
 	EPHY_PREFS_STATE_HISTORY_DATE_FILTER_LAST_TWO_DAYS,
-	EPHY_PREFS_STATE_HISTORY_DATE_FILTER_LAST_THREE_DAYS
+	EPHY_PREFS_STATE_HISTORY_DATE_FILTER_LAST_THREE_DAYS,
+	EPHY_PREFS_STATE_HISTORY_DATE_FILTER_LAST_TEN_DAYS,
+	EPHY_PREFS_STATE_HISTORY_DATE_FILTER_EVER,
 } EphyPrefsStateHistoryDateFilter;
 
 #define EPHY_PREFS_UI_SCHEMA			"org.gnome.Epiphany.ui"
