@@ -24,10 +24,8 @@
 #ifndef EPHY_WINDOW_H
 #define EPHY_WINDOW_H
 
-#include "ephy-embed.h"
+#include "ephy-web-view.h"
 
-#include <glib-object.h>
-#include <glib.h>
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS
@@ -63,12 +61,10 @@ EphyWindow	 *ephy_window_new		  (void);
 EphyWindow	 *ephy_window_new_with_chrome	  (EphyWebViewChrome chrome,
 						   gboolean is_popup);
 
-GObject		 *ephy_window_get_ui_manager	  (EphyWindow *window);
+GtkUIManager	 *ephy_window_get_ui_manager	  (EphyWindow *window);
 
 GtkWidget	 *ephy_window_get_notebook	  (EphyWindow *window);
 
-GtkWidget        *ephy_window_get_find_toolbar    (EphyWindow *window);
-
 void		  ephy_window_load_url		  (EphyWindow *window,
 						   const char *url);
 
@@ -77,15 +73,6 @@ void		  ephy_window_set_zoom		  (EphyWindow *window,
 
 void		  ephy_window_activate_location	  (EphyWindow *window);
 const char       *ephy_window_get_location        (EphyWindow *window);
-void              ephy_window_set_location        (EphyWindow *window,
-                                                   const char *address);
-
-EphyEmbedEvent	 *ephy_window_get_context_event	  (EphyWindow *window);
-
-void		  ephy_window_set_downloads_box_visibility (EphyWindow *window,
-							    gboolean show);
-
-GtkActionGroup   *ephy_window_get_toolbar_action_group (EphyWindow *window);
 
 G_END_DECLS
 
